@@ -3,11 +3,11 @@
 #' A function that bins patches of a mesh surface that share general orientation and
 #' sums the number of unique patches given certain parameters Modified into
 #' 3D from the original 2.5D method described by Evans et al. (2007) High-level
-#' similarity of dentitions in carnivorans and rodents.Nature 445:78-81 doi: 10.1038
-#' nature05433
+#' similarity of dentitions in carnivorans and rodents. Nature 445:78-81 doi:
+#' \href{https://www.nature.com/articles/nature05433}{10.1038/nature05433}
 #'
 #' @param plyFile An object of classes "mesh3d" and "shape3d" with
-#' calculated normals 
+#' calculated vertex normals 
 #' @param rotation Rotates the file in degrees about the center vertical
 #' axis
 #' @param minimum_faces Minimum number of ply faces required
@@ -16,19 +16,17 @@
 #' patch must occupy to be counted towards the total patch count
 #' 
 #' @details The function requires a mesh object created by reading in a ply file utilizing
-#'  either the read.ply, vcgPlyread, or read.AVIZO.ply function
+#' either the, \code{\link[Rvcg]{vcgPlyRead}} function.
 #' 
 #' Orientation patch count is calculated on meshes that represent specimen surfaces
 #' and have already been downsampled to 10,000 faces and pre-smoothed in a 3D
-#' data editing program. Alignment of the point cloud will have a large effect on patch
-#' orientation and must be done in a 3D data editing program such as Avizo, or using
-#' the R package {auto3dgm} prior to creating and reading in the ply file. The
+#' data editing program. Alignment of the surface will have a large effect on patch
+#' orientation and must be performed in a 3D data editing program such as Avizo. The
 #' occlusal surface of the specimen must be made parallel to the X- and Y-axes and
 #' perpendicular to the Z-axis.
 #' 
-#' The default for minimum_faces is to ignore patches consisting of only a single face
+#' The default for minimum_faces is to ignore patches consisting of two or fewer faces
 #' on the mesh. Changing the minimum_area value will disable minimum_faces.
-#' 
 #'
 #' @export
 #' OPC
@@ -48,7 +46,8 @@ OPC <- function(plyFile, rotation=0, minimum_faces=3, minimum_area=0) {
   plyFile <- Directional_Bins(plyFile, rotation)
   
   ### Add Face Areas ###
-  plyFile <- face_areas(plyFile)
+  Areas <- vcgArea(plyFile, perface = TRUE)
+  plyFile$Face_Areas <- Areas$pertriangle
   
   ### Create Indexed Pairs of Faces, Sorted by Directional Bins ###
   indexed_pairs <- index_paired_directed_faces(plyFile)
