@@ -1,23 +1,29 @@
 #' Plotting subfunction for making slope plot legend
 #'
 #' @param colors provided from Slope3d
-#' @param maskNegatives logical whether to mask
+#' @param maskNegatives logical whether to mask faces with negative slopes values
+#' @param size Numeric for legend scaling factor
+#' @details This is an internal function which builds a Slope plot legend
 #'
+#' The legend will reflect the elements used in the plot. This is an internal
+#' function. Users will have little need to call or interact with it.
+#'
+#' @noRd
 
 
-Slope_Legend <- function(colors=colors, maskNegatives=T) 
+Slope_Legend <- function(colors=colors, maskNegatives=T, size=1) 
 {
 	colorsfunc <- colorRamp(colors)
 	par(ann=F, mar=c(0,0,0,0))
-		layout(matrix(1:2,ncol=2), widths=c(0.75, 0.25))
-		plot(1,1, type='n', axes=F)
-		lineSize <- 2
-		textSize <- 1.75
-		rectSize <- 1
-		colorslist <- colorsfunc(rev(seq(0, 1, 0.001)))
-		colorslist <- apply(colorslist, 1, function(x) rgb(x[1], x[2], x[3], maxColorValue=255))
-		legend_gradient <- as.raster(matrix(colorslist, ncol=1))
-		XPos1 <- 1.15                     #X location of center (center of title, left edge legend text)
+	layout(matrix(1:2,ncol=2), widths=c(0.75, 0.25))
+	plot(1,1, type='n', axes=F)
+	lineSize <- 2 * size
+	textSize <- 1.75 * size
+	rectSize <- size
+	colorslist <- colorsfunc(rev(seq(0, 1, 0.001)))
+	colorslist <- apply(colorslist, 1, function(x) rgb(x[1], x[2], x[3], maxColorValue=255))
+	legend_gradient <- as.raster(matrix(colorslist, ncol=1))
+	XPos1 <- 1.15                     #X location of center (center of title, left edge legend text)
   XPos2 <- XPos1-(0.55*rectSize)    #X location of left edge rectangle
   XPos3 <- XPos1-(0.05*rectSize)    #X location of right edge rectangle
   XPos4 <- XPos1-(0.45*rectSize)    #X location of inside of left tic marks
@@ -46,4 +52,4 @@ Slope_Legend <- function(colors=colors, maskNegatives=T)
   	rect(XPos2, YPos5, XPos3, YPos4, lwd=lineSize, col=edgeblack, border="black")
     text(x=XPos1, y=YPos6, labels="Negative\nSlope", cex=textSize, adj=c(0,NA))
   }
-  }
\ No newline at end of file
+}
